# **Reflex** [![](https://gitee.com/tyoui/logo/raw/master/logo/photolog.png)][1]

## 这是一个反射模块集合
[![](https://img.shields.io/badge/个人网站-jtyoui-yellow.com.svg)][1]
[![](https://img.shields.io/badge/Python-3.7-green.svg)]()
[![](https://img.shields.io/badge/BlogWeb-Tyoui-bule.svg)][1]
[![](https://img.shields.io/badge/Email-jtyoui@qq.com-red.svg)]()
[![](https://img.shields.io/badge/反射-reflex-black.svg)]()


### 安装
    pip install jtyoui
    
### 字符串方法反射
```python
from jtyoui.reflex import string_function

if __name__ == '__main__':
    print(string_function('jtyoui', 'BaiDuInfoSearch')('万绮雯').info())
    print(list(string_function('jtyoui', 'f_to_j', str_='載')))
    print(list(string_function('jtyoui', 'f_to_j', '載')))
```

### 网站
>>> [作者的网站](https://blog.jtyoui.com)

### 作者唯一的邮箱
>>> jtyoui@qq.com  



***
[1]: https://blog.jtyoui.com